@@ -1,11 +1,11 @@
-use jsonrpsee::{proc_macros::rpc, core::RpcResult};
+use jsonrpsee::{core::RpcResult, proc_macros::rpc};
 
 // Subscription method must not use the same override name.
 #[rpc(client, server)]
 pub trait DupOverride {
-	#[subscription(name = "one" => "override", item = u8)]
+	#[subscription(name = "subscribeOne" => "override", item = u8)]
 	fn one(&self) -> RpcResult<()>;
-	#[subscription(name = "two" => "override", item = u8)]
+	#[subscription(name = "subscribeTwo" => "override", item = u8)]
 	fn two(&self) -> RpcResult<()>;
 }
 
