@@ -1,9 +1,9 @@
-use jsonrpsee::{proc_macros::rpc, core::RpcResult};
+use jsonrpsee::{core::RpcResult, proc_macros::rpc};
 
 // Subscription method name conflict with notif override.
 #[rpc(client, server)]
 pub trait DupName {
-	#[subscription(name = "one" => "one", item = u8)]
+	#[subscription(name = "one" => "one", unsubscribe = "unsubscribeOne", item = u8)]
 	fn one(&self) -> RpcResult<()>;
 }
 
